@@ -494,7 +494,7 @@ GetDimmIdsFromString(
 
     if (!DimmIdFound) {
       Rc = EFI_NOT_FOUND;
-      PRINTER_SET_MSG(pCmd->pPrintCtx, Rc, L"DIMM not found. Invalid DimmID: " FORMAT_STR_NL, ppDimmIdTokensStr[Index]);
+      PRINTER_SET_MSG(pCmd->pPrintCtx, Rc, PMEM_MODULE_STR L" not found. Invalid DimmID: " FORMAT_STR_NL, ppDimmIdTokensStr[Index]);
       goto FinishError;
     }
   }
@@ -1117,138 +1117,6 @@ Finish:
   return ReturnCode;
 }
 
-/**
-  Match driver command status to CLI return code
-
-  @param[in] Status - NVM_STATUS returned from driver
-
-  @retval - Appropriate EFI return code
-**/
-EFI_STATUS
-MatchCliReturnCode(
-  IN     NVM_STATUS Status
-)
-{
-  EFI_STATUS ReturnCode = EFI_ABORTED;
-  switch (Status) {
-  case NVM_SUCCESS:
-  case NVM_SUCCESS_IMAGE_EXAMINE_OK:
-  case NVM_SUCCESS_FW_RESET_REQUIRED:
-  case NVM_WARN_BLOCK_MODE_DISABLED:
-  case NVM_WARN_2LM_MODE_OFF:
-  case NVM_WARN_MAPPED_MEM_REDUCED_DUE_TO_CPU_SKU:
-  case NVM_WARN_REGION_MAX_PM_INTERLEAVE_SETS_EXCEEDED:
-  case NVM_WARN_REGION_AD_NI_PM_INTERLEAVE_SETS_REDUCED:
-  case NVM_WARN_GOAL_CREATION_SECURITY_UNLOCKED:
-    ReturnCode = EFI_SUCCESS;
-    break;
-
-  case NVM_ERR_PASSPHRASE_TOO_LONG:
-  case NVM_ERR_NEW_PASSPHRASE_NOT_PROVIDED:
-  case NVM_ERR_PASSPHRASE_NOT_PROVIDED:
-  case NVM_ERR_PASSPHRASES_DO_NOT_MATCH:
-  case NVM_ERR_IMAGE_FILE_NOT_VALID:
-  case NVM_ERR_SENSOR_NOT_VALID:
-  case NVM_ERR_SENSOR_CONTROLLER_TEMP_OUT_OF_RANGE:
-  case NVM_ERR_SENSOR_MEDIA_TEMP_OUT_OF_RANGE:
-  case NVM_ERR_SENSOR_CAPACITY_OUT_OF_RANGE:
-  case NVM_ERR_SENSOR_ENABLED_STATE_INVALID_VALUE:
-  case NVM_ERR_UNSUPPORTED_BLOCK_SIZE:
-  case NVM_ERR_NONE_DIMM_FULFILLS_CRITERIA:
-  case NVM_ERR_INVALID_NAMESPACE_CAPACITY:
-  case NVM_ERR_NAMESPACE_TOO_SMALL_FOR_BTT:
-  case NVM_ERR_REGION_NOT_ENOUGH_SPACE_FOR_PM_NAMESPACE:
-  case NVM_ERR_RESERVE_DIMM_REQUIRES_AT_LEAST_TWO_DIMMS:
-  case NVM_ERR_PERS_MEM_MUST_BE_APPLIED_TO_ALL_DIMMS:
-  case NVM_ERR_INVALID_PARAMETER:
-    ReturnCode = EFI_INVALID_PARAMETER;
-    break;
-
-  case NVM_ERR_NOT_ENOUGH_FREE_SPACE:
-  case NVM_ERR_NOT_ENOUGH_FREE_SPACE_BTT:
-    ReturnCode = EFI_OUT_OF_RESOURCES;
-    break;
-
-  case NVM_ERR_DIMM_NOT_FOUND:
-  case NVM_ERR_MANAGEABLE_DIMM_NOT_FOUND:
-  case NVM_ERR_DIMM_EXCLUDED:
-  case NVM_ERR_NO_USABLE_DIMMS:
-  case NVM_ERR_SOCKET_ID_NOT_VALID:
-  case NVM_ERR_REGION_NOT_FOUND:
-  case NVM_ERR_NAMESPACE_DOES_NOT_EXIST:
-  case NVM_ERR_REGION_NO_GOAL_EXISTS_ON_DIMM:
-    ReturnCode = EFI_NOT_FOUND;
-    break;
-
-  case NVM_ERR_ENABLE_SECURITY_NOT_ALLOWED:
-  case NVM_ERR_CREATE_GOAL_NOT_ALLOWED:
-  case NVM_ERR_INVALID_SECURITY_STATE:
-  case NVM_ERR_INVALID_PASSPHRASE:
-  case NVM_ERR_SPI_ACCESS_NOT_ENABLED:
-    ReturnCode = EFI_ACCESS_DENIED;
-    break;
-
-  case NVM_ERR_OPERATION_NOT_STARTED:
-  case NVM_ERR_FORCE_REQUIRED:
-  case NVM_ERR_OPERATION_FAILED:
-  case NVM_ERR_DIMM_ID_DUPLICATED:
-  case NVM_ERR_SOCKET_ID_INCOMPATIBLE_W_DIMM_ID:
-  case NVM_ERR_SOCKET_ID_DUPLICATED:
-  case NVM_ERR_UNABLE_TO_GET_SECURITY_STATE:
-  case NVM_ERR_INCONSISTENT_SECURITY_STATE:
-  case NVM_ERR_SECURITY_USER_PP_COUNT_EXPIRED:
-  case NVM_ERR_SECURITY_MASTER_PP_COUNT_EXPIRED:
-  case NVM_ERR_REGION_GOAL_CONF_AFFECTS_UNSPEC_DIMM:
-  case NVM_ERR_REGION_CURR_CONF_AFFECTS_UNSPEC_DIMM:
-  case NVM_ERR_REGION_GOAL_CURR_CONF_AFFECTS_UNSPEC_DIMM:
-  case NVM_ERR_REGION_CONF_APPLYING_FAILED:
-  case NVM_ERR_REGION_CONF_UNSUPPORTED_CONFIG:
-  case NVM_ERR_DUMP_FILE_OPERATION_FAILED:
-  case NVM_ERR_LOAD_VERSION:
-  case NVM_ERR_LOAD_INVALID_DATA_IN_FILE:
-  case NVM_ERR_LOAD_IMPROPER_CONFIG_IN_FILE:
-  case NVM_ERR_LOAD_DIMM_COUNT_MISMATCH:
-  case NVM_ERR_NAMESPACE_CONFIGURATION_BROKEN:
-  case NVM_ERR_INVALID_SECURITY_OPERATION:
-  case NVM_ERR_OPEN_FILE_WITH_WRITE_MODE_FAILED:
-  case NVM_ERR_DUMP_NO_CONFIGURED_DIMMS:
-  case NVM_ERR_REGION_NOT_HEALTHY:
-  case NVM_ERR_FAILED_TO_GET_DIMM_REGISTERS:
-  case NVM_ERR_FAILED_TO_UPDATE_BTT:
-  case NVM_ERR_SMBIOS_DIMM_ENTRY_NOT_FOUND_IN_NFIT:
-  case NVM_ERR_IMAGE_FILE_NOT_COMPATIBLE_TO_CTLR_STEPPING:
-  case NVM_ERR_IMAGE_EXAMINE_INVALID:
-  case NVM_ERR_FIRMWARE_API_NOT_VALID:
-  case NVM_ERR_FIRMWARE_VERSION_NOT_VALID:
-  case NVM_ERR_REGION_GOAL_NAMESPACE_EXISTS:
-  case NVM_ERR_REGION_REMAINING_SIZE_NOT_IN_LAST_PROPERTY:
-  case NVM_ERR_ARS_IN_PROGRESS:
-  case NVM_ERR_FWUPDATE_IN_PROGRESS:
-  case NVM_ERR_OVERWRITE_DIMM_IN_PROGRESS:
-  case NVM_ERR_UNKNOWN_LONG_OP_IN_PROGRESS:
-  case NVM_ERR_APPDIRECT_IN_SYSTEM:
-  case NVM_ERR_OPERATION_NOT_SUPPORTED_BY_MIXED_SKU:
-  case NVM_ERR_SECURE_ERASE_NAMESPACE_EXISTS:
-  case NVM_ERR_CREATE_NAMESPACE_NOT_ALLOWED:
-    ReturnCode = EFI_ABORTED;
-    break;
-
-  case NVM_ERR_OPERATION_NOT_SUPPORTED:
-  case NVM_ERR_ERROR_INJECTION_BIOS_KNOB_NOT_ENABLED:
-    ReturnCode = EFI_UNSUPPORTED;
-    break;
-
-  case NVM_ERR_FIRMWARE_ALREADY_LOADED:
-    ReturnCode = EFI_ALREADY_STARTED;
-    break;
-
-  default:
-    ReturnCode = EFI_ABORTED;
-    break;
-  }
-  return ReturnCode;
-}
-
 /**
   Get free space of volume from given path
 
@@ -2603,7 +2471,7 @@ CONST CHAR16 *GetDimmIDStr(
   @retval Size String of user display preference
 **/
 CONST CHAR16 *GetDisplaySizeStr(
-  IN  UINT8 DisplaySizeIndex
+  IN  UINT16 DisplaySizeIndex
 )
 {
   if (DisplaySizeIndex >= DISPLAY_SIZE_MAX_SIZE) {
