@@ -84,6 +84,7 @@ extern int cov_dumpData(void);
 extern void nvm_current_cmd(struct Command Command);
 extern BOOLEAN ConfigIsDdrtProtocolDisabled();
 extern BOOLEAN ConfigIsLargePayloadDisabled();
+extern int g_fast_path;
 #else
 #include "DeletePcdCommand.h"
 EFI_GUID gNvmDimmConfigProtocolGuid = EFI_DCPMM_CONFIG2_PROTOCOL_GUID;
@@ -575,7 +576,7 @@ UefiMain(
 #endif
 
 #ifdef OS_BUILD
-        if (!Command.ExcludeDriverBinding) {
+        if (!Command.ExcludeDriverBinding && !g_fast_path) {
           Rc = NvmDimmDriverDriverBindingStart(&gNvmDimmDriverDriverBinding, FakeBindHandle, NULL);
         }
 #endif
@@ -583,7 +584,7 @@ UefiMain(
         Rc = ExecuteCmd(&Command);
 
 #ifdef OS_BUILD
-        if (!Command.ExcludeDriverBinding) {
+        if (!Command.ExcludeDriverBinding && !g_fast_path) {
           NvmDimmDriverDriverBindingStop(&gNvmDimmDriverDriverBinding, FakeBindHandle, 0, NULL);
         }
 #endif
@@ -642,10 +643,7 @@ RegisterNonAdminUserCommands(
 
   NVDIMM_ENTRY();
   Rc = RegisterCommand(&VersionCommand);
-  if (EFI_ERROR(Rc)) {
-    goto done;
-  }
-done:
+
   NVDIMM_EXIT_I64(Rc);
   return Rc;
 }
@@ -731,10 +729,12 @@ RegisterCommands(
     goto done;
   }
 
+#ifndef OS_BUILD
   Rc = RegisterDeleteDimmCommand();
   if (EFI_ERROR(Rc)) {
     goto done;
   }
+#endif
 
   // Persistent Memory Provisioning Commands
   Rc = RegisterShowRegionsCommand();
@@ -1120,7 +1120,7 @@ EFI_STATUS showVersion(struct Command *pCmd)
     ReturnCode = GetPreferredDimmIdAsString(pDimms[DimmIndex].DimmHandle, pDimms[DimmIndex].DimmUid, DimmStr, MAX_DIMM_UID_LENGTH);
     if (EFI_ERROR(ReturnCode)) {
       ReturnCode = EFI_ABORTED;
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"Failed to determine DCPMM id for DCPMM ID %d", pDimms[DimmIndex].DimmHandle);
+      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"Failed to determine " PMEM_MODULE_STR L" id for " PMEM_MODULE_STR " ID %d", pDimms[DimmIndex].DimmHandle);
       goto Finish;
     }
 
@@ -1128,7 +1128,7 @@ EFI_STATUS showVersion(struct Command *pCmd)
       (pDimms[DimmIndex].FwVer.FwApiMajor == MAX_FIS_SUPPORTED_BY_THIS_SW_MAJOR &&
         pDimms[DimmIndex].FwVer.FwApiMinor > MAX_FIS_SUPPORTED_BY_THIS_SW_MINOR)) {
       DimmFromTheFutureCount++;
-      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"DCPMM " FORMAT_STR L" supports FIS %d.%d\r\n",
+      PRINTER_SET_MSG(pPrinterCtx, ReturnCode, PMEM_MODULE_STR L" " FORMAT_STR L" supports FIS %d.%d\r\n",
         DimmStr,
         pDimms[DimmIndex].FwVer.FwApiMajor,
         pDimms[DimmIndex].FwVer.FwApiMinor);
@@ -1137,7 +1137,7 @@ EFI_STATUS showVersion(struct Command *pCmd)
   }
 
   if (DimmFromTheFutureCount > 0) {
-    PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"This ipmctl software version predates the firmware interface specification version (FIS | FWAPIVersion: %d.%d) for %d DCPMM(s). It is recommended to update ipmctl.\r\n",
+    PRINTER_SET_MSG(pPrinterCtx, ReturnCode, L"This ipmctl software version predates the firmware interface specification version (FIS | FWAPIVersion: %d.%d) for %d " PMEM_MODULE_STR L"(s). It is recommended to update ipmctl.\r\n",
       MAX_FIS_SUPPORTED_BY_THIS_SW_MAJOR,
       MAX_FIS_SUPPORTED_BY_THIS_SW_MINOR,
       DimmFromTheFutureCount);
