@@ -103,7 +103,7 @@ EFI_STATUS
 EFIAPI
 DefaultPassThru(
   IN     struct _DIMM *pDimm,
-  IN OUT FW_CMD *pCmd,
+  IN OUT NVM_FW_CMD *pCmd,
   IN     UINT64 Timeout
 )
 {
